/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'iframe', 'es', {
	border: 'Mostrar borde del marco',
	noUrl: 'Por favor, escriba la dirección del iframe',
	scrolling: 'Activar barras de desplazamiento',
	title: 'Propiedades de iframe',
	toolbar: 'IFrame',
	tabindex: 'Remove from tabindex' // MISSING
} );
